#[non_exhaustive]pub enum RenderError {
ImageSizeTooSmall,
ImageSizeTooLarge,
Io(Error),
Image(ImageError),
}Expand description
Errors returned while rendering a QR Code symbol.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ImageSizeTooSmall
The requested output is too small for an integer module scale and quiet zone.
ImageSizeTooLarge
The requested output dimensions overflow a supported image size.
Io(Error)
Available on crate feature
std only.An input or output operation failed.
Image(ImageError)
Available on crate feature
image only.PNG encoding failed.