#[non_exhaustive]pub enum SymbolErrorCorrection {
DetectionOnly,
Low,
Medium,
Quartile,
High,
}Available on crate features
micro-qr or qr or rmqr only.Expand description
The error correction level written to an encoded symbol.
The available variants depend on the enabled symbol family features.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
DetectionOnly
Available on crate feature
micro-qr only.Detects errors in a Micro QR M1 symbol without correcting them.
Low
Uses the Low error correction level.
Medium
Uses the Medium error correction level.
Quartile
Uses the Quartile error correction level.
High
Available on crate features
qr or rmqr only.Uses the High error correction level.