ToQRText

Trait ToQRText 

pub trait ToQRText {
    // Required method
    fn to_qr_text(&self) -> String;
}
Converts a value to text for QR Code encoding.

Implementations can use a shorter equivalent spelling when the value has more than one text representation. The optional url feature implements this trait for url::Url.

Required Methods

fn to_qr_text(&self) -> String

Returns the text to encode.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ToQRText for Url

Available on crate feature url only.

Implementors