pub struct Symbol { /* private fields */ }Available on crate features
micro-qr or qr or rmqr only.Expand description
An immutable encoded QR Code, Micro QR Code or rMQR symbol.
Implementations
Sourceimpl Symbol
impl Symbol
Sourcepub const fn version(&self) -> SymbolVersion
pub const fn version(&self) -> SymbolVersion
Returns the encoded symbol version.
Sourcepub const fn error_correction(&self) -> SymbolErrorCorrection
pub const fn error_correction(&self) -> SymbolErrorCorrection
Returns the error correction level written to the symbol.
Sourcepub const fn structured_append(&self) -> Option<StructuredAppendInfo>
Available on crate feature qr only.
pub const fn structured_append(&self) -> Option<StructuredAppendInfo>
qr only.Returns Structured Append metadata when this symbol belongs to a sequence.
Sourcepub fn module(&self, x: usize, y: usize) -> Option<bool>
pub fn module(&self, x: usize, y: usize) -> Option<bool>
Returns a module or None when the coordinates are outside the symbol.